import scrapy, json, re
from datetime import datetime, date, timedelta, tzinfo

"""
Esta version descarga todas las noticias contenidas en la pagina, sin necesidad
de una fecha especifica.
USO:

scrapy crawl noticias -t json --nolog -o noticias.json

Genera un archivo JSON con todas las noticias disponibles. El archivo 'parse_date_file.py'
puede servir para clasificar dichas noticias en sus respectivas fechas.
"""


TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
	return TAG_RE.sub('', text)


class UTC(tzinfo):
	"""clase para el 'time zone' (zona horaria)"""

	def utcoffset(self, dt):
		# zona horaria para yucatan (centro de mexico): utc-6
		return timedelta(hours=-6)

	def tzname(self, dt):
		# nombre de la zona horaria
		return 'UTC-6'


class NoticiasItem(scrapy.Item):
	title = scrapy.Field()
	text = scrapy.Field()
	date = scrapy.Field()
	location = scrapy.Field()
	author = scrapy.Field()
	topic = scrapy.Field()
	url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
	name = "noticias"
	
	def start_requests(self):
		self.tz = UTC()
		self.baseURL = 'https://www.lajornadamaya.mx'
		section_list = [('yucatan',123,'Yucatan'), ('quintana-roo',52,'Quintana Roo'),
						('campeche',32,'Campeche'), ('opinion',0,'Opinion'), ('deportes',91,'Deportes'),
						('nacional',100,'Nacional'), ('internacional',87,'Internacional')]
		# section_list = [('opinion',0,'Opinion')]

		for section in section_list:
			self.section = section
			if not ( section[0] == 'opinion' ):
				for page in range(0,section[1]+1):
					yield scrapy.Request(url=self.baseURL+'/'+section[0]+'?p='+str(page), callback=self.parse)
			else:
				yield scrapy.Request(url=self.baseURL+'/notas?opinion', callback=self.parse)


	def parse(self, response):
		json_response = json.loads(response.text)

		if not ( self.section[0] == 'opinion' ):
			json_list = json_response
		else:
			json_list = json_response['articles']

		for line in json_list:
			item = NoticiasItem()

			d = line['publishDate']
			if len(d) == 10:
				d = map(int, d.split('-'))
				d = datetime(d[0], d[1], d[2], tzinfo=self.tz).isoformat('T')
				
			elif len(d) == 19:
				d, t = d.split(' ')
				d = map(int, d.split('-'))
				t = map(int, t.split(':'))
				d = datetime(d[0],d[1],d[2],t[0],t[1],t[2],tzinfo=self.tz).isoformat('T')

			item['date'] = d
			
			item['topic'] = self.section[2]
			item['title'] = line['name']
			if not ( self.section[0] == 'opinion' ):
				request = scrapy.Request(url=self.baseURL+line['url'], callback=self.parse_item)
			else:
				request = scrapy.Request(url=self.baseURL+'/'+line['publishDate'][:line['publishDate'].rfind(' ')]+'/'+line['uriComponent'], callback=self.parse_item)
			request.meta['item'] = item
			yield request


	def parse_item(self, response):
		item = response.meta['item']
		text = ''
		for paragraph in response.xpath('//*[@class="txt"]').extract():
			text += remove_tags(paragraph) + '\n'
		item['text'] = text
		item['url'] = response.url
		# print item['title']
		yield item

