# -*- coding: utf-8 -*-
import scrapy, re
from laJornadaGro.items import NoticiasItem
from datetime import datetime, timedelta, tzinfo

"""
MEDIO:
La Jornada Guerrero, Gro.
Esta version se encarga de la descarga de la nueva pagina de La Jornada Guerrero
con url: 'http://www.lajornadaguerrero.com.mx'
Esta version descarga noticias a partir del 2017.08.15
Uso:
scrapy crawl noticias --nolog -s filename=2017-09-18.json -a year=2017 -a month=9 -a day=18
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class UTC(tzinfo):
    """clase para el 'time zone' (zona horaria)"""

    def utcoffset(self, dt):
        # zona horaria para guerrero (centro de mexico): utc-6
        return timedelta(hours=-6)

    def tzname(self, dt):
        # nombre de la zona horaria
        return 'UTC-6'


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        self.tz = UTC()
        year = getattr(self, 'year', None)
        month = getattr(self, 'month', None)
        day = getattr(self, 'day', None)

        self.parse_month = {'Ene': '01', 'Feb': '02', 'Mar': '03', 'Abr': '04', 'May': '05', 'Jun': '06',
                                                'Jul': '07', 'Ago': '08', 'Sep': '09', 'Oct': '10', 'Nov': '11', 'Dic': '12'}

        # self.baseURL = 'http://www.ljg.com.mx'
        self.baseURL = "http://www.lajornadaguerrero.com.mx"
        url = "/index.php?option=com_k2&view=itemlist&task=date&year="+year+"&month="+month+"&day="+day+"&Itemid=588"

        yield scrapy.Request(url=self.baseURL+url, callback=self.parse)


    def parse(self, response):
        yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)

        pagination = response.xpath('//ul[@class="pagination"]/li/a/@href').extract()[:-2]
        if len(pagination) > 0:
            for page in range(0, len(pagination)):
                yield scrapy.Request(url=self.baseURL+pagination[page], callback=self.parse_page)


    def parse_page(self, response):
        for li in response.xpath('//*[@class="genericItemView"]/div[@class="genericItemHeader"]/h2/a/@href').extract():
            yield scrapy.Request(url=self.baseURL+li, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        path_list = ['//*[@class="itemIntroText"]/p', '//*[@class="itemFullText"]/p']
        text = ''

        d = response.xpath('//span[@class="itemDateCreated"]/text()').extract_first()
        if d is not None:
            d = d.replace('\n','')
            d = d.replace('\t','')
            d = d.replace(',','')
            m = d[:d.find(' ')]
            d = d.replace(m, self.parse_month[m])
            # item['date'] = datetime.strptime(d, '%m %d %Y').date()
            d = map(int, d.split(' '))
            item['date'] = datetime(d[2],d[0],d[1],tzinfo=self.tz).isoformat('T')

        title = response.xpath('//*[@class="itemHeader"]/h2/text()').extract_first()
        if title is not None:
            title = title.replace('\n','')
            title = title.replace('\t','')
            title = title.lstrip()
            title = title.rstrip()
            item['title'] = title

        item['topic'] = response.xpath('//*[@class="itemCategory"]/a/text()').extract_first()

        for path in path_list:
            for p in response.xpath(path).extract():
                text += remove_tags(p)
        item['text'] = text

        item['url'] = response.url

        # print item['url']
        yield item

