# -*- coding: utf-8 -*-
import scrapy, re
from laJornadaOte.items import NoticiasItem

"""
MEDIO:
La Jornada de Oriente, Puebla
USO:
scrapy crawl noticias --nolog -s filename=2017-03-22.json -a year=2017 -a month=3 -a day=22
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        year = getattr(self, 'year', None)
        month = getattr(self, 'month', None)
        day = getattr(self, 'day', None)

        self.baseURL='http://www.lajornadadeoriente.com.mx/'+year+'/'+month+'/'+day

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        for link in response.xpath('//div[@class="mas_noticias"]/ul[@class="sollet"]/li/a/@href').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''
        item['title'] = response.xpath('//h1[@itemprop="headline"]/text()').extract_first()
        ## la fecha de la noticia ya incluye la zona horaria
        item['date'] = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()
        item['topic'] = response.xpath('//span[@itemprop="genre"]/text()').extract_first()

        for paragraph in response.xpath('//span[@itemprop="articleBody"]').extract():
            text += remove_tags(paragraph) + '\n'
        item['text'] = text
        item['url'] = response.url

        # print item['title']
        yield item

