# -*- coding: utf-8 -*-
import scrapy, re
from laJornadaSanLuis.items import NoticiasItem

"""
MEDIO:
La Jornada de San Luis, San Luis Potosi
Uso:
scrapy crawl noticias --nolog -s filename=2017-03-22.json -a year=2017 -a month=3 -a day=22
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        year = getattr(self, 'year', None)
        month = getattr(self, 'month', None)
        day = getattr(self, 'day', None)

        self.baseURL='http://lajornadasanluis.com.mx/'+year+'/'+month+'/'+day

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)

        pagination = response.xpath('//div[@class="pages"]/a/@href').extract()
        if len(pagination) > 0:
            pagination = pagination[-1].strip('/')
            pages = int(pagination[pagination.rfind('/')+1:])
            for page in range(1, pages):
                yield scrapy.Request(url=self.baseURL+'/page/'+str(page+1), callback=self.parse_page)


    def parse_page(self, response):
        for link in response.xpath('//*[@class="post-title"]/h2/a/@href').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''
        ## la fecha de la noticia ya incluye la zona horaria
        d = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()
        if d is None:
            d = response.xpath('//time[@class="entry-date updated"]/@datetime').extract_first()
        item['date'] = d

        item['title'] = response.css('h1.entry-title::text').extract_first()

        item['topic'] = response.xpath('//ul[@class="post-categories"]/li/a/text()').extract_first()

        for paragraph in response.xpath('//p[@style="text-align: justify;"]/text()').extract():
            text += remove_tags(paragraph) + '\n'
        item['text'] = text
        item['url'] = response.url
        # print item['title']
        yield item

