# -*- coding: utf-8 -*-
import scrapy, re
from sona893.items import NoticiasItem

"""
MEDIO:
Sona 89.3, Yucatán
USO:
scrapy crawl noticias --nolog -s filename=2017-03-22.json -a year=2017 -a month=3 -a day=22
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        year = getattr(self, 'year', None)
        month = getattr(self, 'month', None)
        day = getattr(self, 'day', None)

        self.baseURL = "http://sona893.fm/" + year + "/" + month + "/" + day

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)

        pagination = response.css('div.pagination').css('a::attr(href)').extract()
        if len(pagination) > 0:
            pagination = pagination[-1].strip('/')
            pages = int(pagination[pagination.rfind('/')+1:])

            for page in range(1, pages):
                yield scrapy.Request(url=self.baseURL+"/page/"+str(page+1), callback=self.parse_page)


    def parse_page(self, response):
        for post in response.css('div.mosaicflow').css('div.post'):
            item = NoticiasItem()
            item['topic'] = post.css('a.custom_cat_class_Kesha::text').extract_first()
            item['title'] = post.xpath('./h1/a/@title').extract_first()
            request = scrapy.Request(url=post.xpath('./h1/a/@href').extract_first(), callback=self.parse_item)
            request.meta['item'] = item

            yield request

    def parse_item(self, response):
        item = response.meta['item']
        text = ''

        d = response.xpath('/html/head/meta[@property="article:published_time"]').css('::attr(content)').extract_first()
        ## '-06:00' corresponde al UTC-6, zona horaria de yucatan (centro de mexico)
        if d[-6:] != '-06:00':
            d = d[:-6] + '-06:00'
        item['date'] = d

        for paragraph in response.css('div.single_text').css('p').extract():
            text += remove_tags(paragraph) + '\n'
        item['text'] = text
        item['url'] = response.url

        # print item['title']
        yield item

