# -*- coding: utf-8 -*-
import scrapy, re
from tribunaCabos.items import NoticiasItem

"""
MEDIO:
Tribuna de los Cabos, Baja California Sur
USO:
scrapy crawl noticias -t json --nolog -o noticias.json -a year=2017 -a month=3 -a day=5
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)

""" Regular expression for parsing location """
# LOC_RE = re.compile(ur'.+,\s+\d?\d\s+[a-zA-Z]+\.?\s\([^\)]+\)\s?\.-?\u2013?\s?', re.UNICODE)
LOC_RE = re.compile(ur'.+?(\d?\d[\s-][a-zA-Z]+)?\s?(\([^\)]+\))?\s?\.[\u2013-]\s?', re.UNICODE)
DAT_RE = re.compile(ur',?\s?(\d?\d[\s-][a-zA-Z]+)?\s?(\([^\)]+\))?\s?\.[\u2013-]\s?', re.UNICODE)
DAT2_RE = re.compile(r',?\sa\s\d{1,2}\sde\s[a-zA-Z]+\sde\s\d{4}')


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        year = getattr(self, "year", None)
        month = getattr(self, "month", None)
        day = getattr(self, "day", None)

        self.baseURL = "http://www.tribunadeloscabos.com.mx/" + year + "/" + month + "/" + day

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        for link in response.xpath('//*[@id="content"]').css('h2').css('a::attr(href)').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)

        previousPage = response.xpath('//li[@class="previous"]/a/@href').extract_first()
        yield scrapy.Request(url=previousPage, callback=self.parse)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        "La fecha obtenida ya incluye formato y zona horaria"
        item['date'] = response.xpath('//time[@class="entry-date published"]/@datetime').extract_first()
        item['title'] = remove_tags(response.xpath('//header[@class="entry-header"]/h1').extract_first()).strip()
        item['topic'] = response.xpath('//*[@class="above-entry-meta"]/span/a/text()').extract_first()

        author = response.xpath('//span[@class="author vcard"]/a/text()').extract_first()
        if author is not None and author != '':
            item['author'] = author

        bodyText = response.xpath('//*[@class="entry-content clearfix"]/p').extract()
        for i in range(0, len(bodyText)):
            p = remove_tags(bodyText[i])
            if i <= 1:
                p = p.lstrip()
                result = LOC_RE.match(p)
                if result:
                    loc = DAT_RE.sub('', result.group(0))
                    item['location'] = DAT2_RE.sub('', loc)
                    p = LOC_RE.sub('', p)

            text += p + "\n"
        item['text'] = text

        item['url'] = response.url

        yield item


