# -*- coding: utf-8 -*-
import scrapy, re, json
from unoMasUno.items import NoticiasItem
from datetime import datetime, timedelta, tzinfo

"""
MEDIO:
Uno Más Uno, Yucatán
USO:
scrapy crawl noticias --nolog -s filename=2017-09-22.json -a year=2017 -a month=9 -a day=22
"""


TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class UTC(tzinfo):
    """clase para el 'time zone' (zona horaria)"""

    def utcoffset(self, dt):
        # zona horaria para hidalgo (centro de mexico): utc-6
        return timedelta(hours=-6)

    def tzname(self, dt):
        # nombre de la zona horaria
        return 'UTC-6'


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        self.tz = UTC()
        self.year = getattr(self, 'year', None)
        self.month = getattr(self, 'month', None)
        self.day = getattr(self, 'day', None)
        self.date_parser = {'enero': 1,      'febrero': 2,  'marzo': 3,      'abril': 4,
                            'mayo': 5,       'junio': 6,    'julio': 7,      'agosto': 8,
                            'septiembre': 9, 'octubre': 10, 'noviembre': 11, 'diciembre': 12}

        self.baseURL = "http://www.unomasuno.com.mx/" + self.year + "/" + self.month + "/" + self.day

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)

        pagination = response.xpath('//*[@class="pagination"]/a[@class="last"]/@href').extract_first()
        if pagination is None:
            pagination = response.xpath('//*[@class="pagination"]/a/@href').extract()

            if len(pagination) > 0:
                pagination = pagination[-1].strip('/')
                pages = int(pagination[pagination.rfind('/')+1:])

                for page in range(1, pages):
                    yield scrapy.Request(url=self.baseURL+"/page/"+str(page+1), callback=self.parse_page)

        else:
            pagination = pagination.strip('/')
            pages = int(pagination[pagination.rfind('/')+1:])

            for page in range(1, pages):
                yield scrapy.Request(url=self.baseURL+"/page/"+str(page+1), callback=self.parse_page)


    def parse_page(self, response):
        for link in response.xpath('//h2[@class="post-box-title"]/a/@href').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        try:
            jsonInfo = response.xpath('//script[@type="application/ld+json"]').extract_first()
            jsonInfo = json.loads(remove_tags(jsonInfo))
            dat = jsonInfo['datePublished']
        except:
            try:
                d = response.xpath('//p[@class="post-meta"]/span/text()').extract_first()
                d = d.replace(',', '').split(' ')
                dat = datetime(int(d[2]), self.date_parser[d[1].lower()], int(d[0]), tzinfo=self.tz).isoformat("T")
            except:
                dat = datetime(int(self.year), int(self.month), int(self.day), tzinfo=self.tz).isoformat("T")
        item['date'] = dat

        item['topic'] = response.xpath('//span[@typeof="v:Breadcrumb"]/a/text()').extract()[1]
        item['title'] = response.xpath('//*[@class="post-inner"]/h1/span/text()').extract_first()

        for p in response.xpath('//*[@class="entry"]/p').extract():
            text += remove_tags(p) + '\n'

        item['text'] = text
        item['url'] = response.url

        # print item['title']
        yield item

